@@ -1,5 +1,5 @@
 from schema import Schema, Document, create_document
-from fields import *
 from file_fields import FileField
-from common import get_schema
+from common import get_base_document
 from manager import Manager
+from fields import *
