@@ -279,6 +279,8 @@ class DecimalField(BaseField):
         return str(val)
     
     def to_python(self, val, parent=None):
+        if val is None:
+            return None
         return Decimal(val)
 
 class EmailField(CharField):
@@ -336,6 +338,9 @@ class SchemaTypeField(CharField):
             return first_choice + list(zip(self.schemas.keys(), self.schemas.keys()))
             #TODO allow schema to have a display label, perhaps verbose name?
         return first_choice
+    
+    def get_schema_choices(self):
+        return self.get_choices()
 
 class SchemaField(BaseField):
     form_field_class = HiddenSchemaField
@@ -355,6 +360,10 @@ class SchemaField(BaseField):
             return True
         return isinstance(val, self.schema)
     
+    def get_schema_choices(self):
+        field_name = self.schema._meta.typed_field
+        return self.schema._meta.fields[field_name].schemas.items()
+    
     def traverse_dot_path(self, traverser):
         if traverser.remaining_paths:
             name = traverser.next_part
