@@ -31,7 +31,7 @@ class SchemaOptions(object):
     ordering = ['_id']
     
     DEFAULT_NAMES = ['verbose_name', 'db_table', 'ordering', 'schema_key',
-                     'app_label', 'collection', 'virtual', 'proxy',
+                     'app_label', 'collection', 'virtual', 'proxy', 'permissions',
                      'typed_field', 'typed_key']
     
     def __init__(self, meta, app_label=None, parent_fields=[]):
@@ -47,6 +47,7 @@ class SchemaOptions(object):
         self._document = None
         self.typed_field = None
         self.typed_key = None
+        self.permissions = []
     
     def process_values(self, cls):
         cls._meta = self
@@ -173,6 +174,15 @@ class SchemaOptions(object):
     @property
     def many_to_many(self):
         return []
+    
+    def get_add_permission(self):
+        return '%s.add' % self.collection
+
+    def get_change_permission(self):
+        return '%s.change' % self.collection
+
+    def get_delete_permission(self):
+        return '%s.delete' % self.collection
 
 class DocumentOptions(SchemaOptions):
     abstract = False
