@@ -233,14 +233,42 @@ class Schema(object):
             del self[attr]
         else:
             self[attr] = value
+    
+    def serializable_value(self, field_name):
+        try:
+            field = self._meta.get_field_by_name(field_name)[0]
+        except FieldDoesNotExist:
+            return getattr(self, field_name)
+        return getattr(self, field.attname)
+    
+    def __str__(self):
+        if hasattr(self, '__unicode__'):
+            return force_unicode(self).encode('utf-8')
+        return '%s object' % self.__class__.__name__
+    
+    def __eq__(self, other):
+        return isinstance(other, self.__class__) and self.to_primitive(self) == other.to_primitive(other)
+    
+    def __ne__(self, other):
+        return not self.__eq__(other)
+    
+    def __hash__(self):
+        return hash(self.to_primitive(self))
 
 _pending_registered_documents = list()
 
 def _register_document(document_cls):
-    backend = document_cls._meta.get_backend()
-    backend.register_document(document_cls)
-    register_collection(document_cls)
-    document_registered.send(sender=document_cls._meta.collection, document=document_cls)
+    if app_cache_ready():
+        while document_cls:
+            backend = document_cls._meta.get_backend()
+            backend.register_document(document_cls)
+            register_collection(document_cls)
+            document_registered.send_robust(sender=document_cls._meta.collection, document=document_cls)
+            if not _pending_registered_documents:
+                break
+            document_cls = _pending_registered_documents.pop()
+    else:
+        _pending_registered_documents.append(document_cls)
 
 class DocumentBase(SchemaBase):
     options_module = options.DocumentOptions
@@ -304,17 +332,9 @@ class Document(Schema):
             return getattr(self, field_name)
         return getattr(self, field.attname)
     
-    def __str__(self):
-        if hasattr(self, '__unicode__'):
-            return force_unicode(self).encode('utf-8')
-        return '%s object' % self.__class__.__name__
-    
     def __eq__(self, other):
         return isinstance(other, self.__class__) and self.pk == other.pk
 
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
     def __hash__(self):
         return hash((self._meta.collection, self.pk))
 
